<?php
/**
 * Display all Whitish Lite functions and definitions
 *
 * @package Yudlee Themes
 * @subpackage Whitish Lite
 * @since Whitish Lite 1.0
 */

/************************************************************************************************/
if ( ! function_exists( 'whitish_lite_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function whitish_lite_setup() {
	/**
	 * Set the content width based on the theme's design and stylesheet.
	 */
	global $content_width;
	if ( ! isset( $content_width ) ) {
			$content_width=790;
	}

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Whitish Lite, use a find and replace
	 * to change 'whitish-lite' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'whitish-lite', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	add_theme_support('post-thumbnails');

	// Add customizer edit shortcodes
	add_theme_support( 'customize-selective-refresh-widgets' );

	if ( function_exists( 'add_image_size' ) ) {
			add_image_size( 'whitish-lite-featured-page', 500, 400, true );
	}

	/*
	 * Let WordPress manage the document title.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	add_theme_support( 'custom-header' );

	register_nav_menus( array(
		'primary' => __( 'Main Menu', 'whitish-lite' ),
		'footermenu' => __( 'Footer Menu', 'whitish-lite' ),
	) );

	/*
	* Enable support for custom logo.
	*
	*/
	add_theme_support( 'custom-logo', array(
		'flex-width' => true,
		'flex-height' => true,
	) );

	//Indicate widget sidebars can use selective refresh in the Customizer.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * Switch default core markup for comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/**
	 * Add support for the Aside Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'image', 'quote', 'video', 'audio' ) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'whitish_lite_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	add_editor_style( array( 'assets/css/editor-style.css') );

	/**
	* Making the theme Woocommrece compatible
	*/

	add_theme_support( 'woocommerce' );
}
endif; // whitish_lite_setup
add_action( 'after_setup_theme', 'whitish_lite_setup' );

/***************************************************************************************/
function whitish_lite_content_width() {
	if ( is_page_template( 'page-templates/gallery-template.php' ) || is_attachment() ) {
		global $content_width;
		$content_width = 1170;
	}
}
add_action( 'template_redirect', 'whitish_lite_content_width' );

/***************************************************************************************/
if(!function_exists('whitish_lite_get_theme_options')):
	function whitish_lite_get_theme_options() {
	    return wp_parse_args(  get_option( 'whitish_lite_theme_options', array() ), whitish_lite_get_option_defaults_values() );
	}
endif;

/***************************************************************************************/
require get_template_directory() . '/inc/customizer/whitish-lite-default-values.php';
require( get_template_directory() . '/inc/settings/whitish-lite-functions.php' );
require( get_template_directory() . '/inc/settings/custom-header.php' );
require( get_template_directory() . '/inc/settings/whitish-lite-common-functions.php' );
require( get_template_directory() . '/inc/settings/whitish-lite-tgmp.php' );
require get_template_directory() . '/inc/jetpack.php';
require get_template_directory() . '/inc/footer-details.php';
require get_template_directory() . '/page-templates/frontpage-feature.php';

//TGMPA plugin
require get_template_directory() . '/plugin-activation.php';

/************************ Whitish Lite Widgets  *****************************/
require get_template_directory() . '/inc/widgets/widgets-functions/register-widgets.php';

/************************ Whitish Lite Customizer  *****************************/
require get_template_directory() . '/inc/customizer/functions/sanitize-functions.php';
require get_template_directory() . '/inc/customizer/functions/register-panel.php';
function whitish_lite_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector' => '#site-title a',
			'container_inclusive' => false,
			'render_callback' => 'whitish_lite_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector' => '#site-description',
			'container_inclusive' => false,
			'render_callback' => 'whitish_lite_customize_partial_blogdescription',
		) );
	}
	require get_template_directory() . '/inc/customizer/functions/frontpage-features.php';
	require get_template_directory() . '/inc/customizer/functions/contact-us-customizer.php';
	require get_template_directory() . '/inc/customizer/functions/design-options.php';
	require get_template_directory() . '/inc/customizer/functions/theme-options.php';
	require get_template_directory() . '/inc/customizer/functions/social-icons.php';
	require get_template_directory() . '/inc/customizer/functions/featured-content-customizer.php' ;
	require get_template_directory() . '/inc/customizer/functions/color-options.php' ;
}
	/* Color Styles */
	require get_template_directory() . '/inc/settings/color-option-functions.php' ;
/**
* Render the site title for the selective refresh partial.
* @see whitish_lite_customize_register()
* @return void
*/
function whitish_lite_customize_partial_blogname() {
bloginfo( 'name' );
}

/**
* Render the site tagline for the selective refresh partial.
* @see whitish_lite_customize_register()
* @return void
*/
function whitish_lite_customize_partial_blogdescription() {
bloginfo( 'description' );
}
add_action( 'customize_register', 'whitish_lite_customize_register' );

/******************* Whitish Lite Header Display *************************/
function whitish_lite_header_display(){
	$whitish_lite_settings = whitish_lite_get_theme_options();
	$header_display_logo = $whitish_lite_settings['whitish_lite_header_display_logo'];
	if (display_header_text() || ($header_display_logo == 1)) { ?>
		<div id="site-branding"><?php if ($header_display_logo == 1) { whitish_lite_the_custom_logo();} ?>
		<?php if (display_header_text()) {
			if(is_home() || is_front_page()){  ?>
				<h1 id="site-title">
			 <?php } else { ?>
			 	<h2 id="site-title">
			  <?php } ?>
				<a href="<?php echo esc_url(home_url('/'));?>" title="<?php echo esc_attr(get_bloginfo('name', 'display'));?>" rel="home"> <?php bloginfo('name');?> </a>
			<?php if(is_home() || is_front_page() || is_search()){ ?>
				</h1>  <!-- end .site-title -->
			<?php } else { ?> </h2> <!-- end .site-title --> <?php }
		$site_description = get_bloginfo( 'description', 'display' );
		if($site_description){?>
		<p id ="site-description"> <?php bloginfo('description');?> </p> <!-- end #site-description -->
		<?php } ?>
	<?php } ?>
		</div> <!-- end #site-branding -->
		<?php
	}
}
add_action('whitish_lite_site_branding','whitish_lite_header_display');

if ( ! function_exists( 'whitish_lite_the_custom_logo' ) ) :
 	/**
 	 * Displays the optional custom logo.
 	 * Does nothing if the custom logo is not available.
 	 */
 	function whitish_lite_the_custom_logo() {
 	    if ( function_exists( 'the_custom_logo' ) ) {
 	        the_custom_logo();
 	    }
 	}
 	endif;

/* Header Image */
function whitish_lite_header_image_display(){
	$whitish_lite_header_image = get_header_image();
	$whitish_lite_settings = whitish_lite_get_theme_options();
	if(!empty($whitish_lite_header_image) ){
		if (!is_page_template('page-templates/contact-template.php')){ ?>
		<a href="<?php echo esc_url(home_url('/'));?>"><img src="<?php echo esc_url($whitish_lite_header_image);?>" class="header-image" width="<?php echo esc_attr(get_custom_header()->width);?>" height="<?php echo esc_attr(get_custom_header()->height);?>" alt="<?php echo esc_attr(get_bloginfo('name', 'display'));?>"> </a>
	<?php }
	}
		if (is_page_template('page-templates/contact-template.php')){
			if (has_post_thumbnail()){
				$image_id = get_post_thumbnail_id();
				$image_url = wp_get_attachment_image_src($image_id, 'full');
				$image_url1 = $image_url[0];
			?>
					<div class="contact-header" style="background-image:url(<?php echo esc_url($image_url1);?>)">
					</div>
			<?php
			} else {
				?>
					<div class="contact-header" style="background-image:url(<?php echo esc_url($whitish_lite_header_image);?>)">
					</div>
				<?php
			}
		}
}
add_action('whitish_lite_header_image','whitish_lite_header_image_display');

if ( function_exists( 'wp_update_custom_css_post' ) ) {
	$whitish_lite_settings = whitish_lite_get_theme_options();
    $custom_css = ( $whitish_lite_settings['whitish_lite_custom_css']  ? $whitish_lite_settings['whitish_lite_custom_css'] : '');
    $core_css = wp_get_custom_css();
    if ( !empty($custom_css)  && empty($core_css) ) {
        $return = wp_update_custom_css_post( $core_css . $custom_css );
    }
}

  // turn Photon off so we can get the correct image
    $photon_removed = '';
    if (class_exists('Jetpack') && Jetpack::is_module_active('photon'))
    { // check that we are, in fact, using Photon in the first place
        remove_filter( 'image_downsize', array( Jetpack_Photon::instance(), 'filter_image_downsize' ) );
    }